@@ -26,11 +26,26 @@
 #' a table *are not* equal to a specified `value`. The validation function can
 #' be used directly on a data table or with an *agent* object (technically, a
 #' `ptblank_agent` object) whereas the expectation and test functions can only
-#' be used with a data table. The types of data tables that can be used include
-#' data frames, tibbles, database tables (`tbl_dbi`), and Spark DataFrames
-#' (`tbl_spark`). Each validation step or expectation will operate over the
-#' number of test units that is equal to the number of rows in the table (after
-#' any `preconditions` have been applied).
+#' be used with a data table. Each validation step or expectation will operate
+#' over the number of test units that is equal to the number of rows in the
+#' table (after any `preconditions` have been applied).
+#'
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
 #' If providing multiple column names, the result will be an expansion of
@@ -126,8 +141,9 @@
 #' `col_vals_not_equal()` as a validation step is expressed in R code and in the
 #' corresponding YAML representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_vals_not_equal(
 #'     columns = vars(a),
@@ -139,8 +155,11 @@
 #'     label = "The `col_vals_not_equal()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_vals_not_equal:
 #'     columns: vars(a)
@@ -174,11 +193,12 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #'
-#' @examples
-#' # For all of the examples here, we'll
-#' # use a simple table with three numeric
-#' # columns (`a`, `b`, and `c`) and three
-#' # character columns (`d`, `e`, and `f`)
+#' @section Examples:
+#' 
+#' For all of the examples here, we'll use a simple table with three numeric
+#' columns (`a`, `b`, and `c`) and three character columns (`d`, `e`, and `f`).
+#' 
+#' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
 #'     a = c(5, 5, 5, 5, 5, 5),
@@ -188,57 +208,62 @@
 #'     e = LETTERS[c(1:6)],
 #'     f = LETTERS[c(1:6)]
 #'   )
-#'   
+#' 
 #' tbl
+#' ```
 #' 
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()` 
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
 #' 
-#' # Validate that values in column `a`
-#' # are all *not* equal to the value
-#' # of `6`
+#' Validate that values in column `a` are all *not* equal to the value of `6`.
+#' We'll determine if this validation has any failing test units (there are 6
+#' test units, one for each row).
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(tbl) %>%
-#'   col_vals_not_equal(vars(a), 6) %>%
+#'   create_agent(tbl = tbl) %>%
+#'   col_vals_not_equal(columns = vars(a), value = 6) %>%
 #'   interrogate()
+#' ```
 #' 
-#' # Determine if this validation
-#' # had no failing test units (there
-#' # are 6 test units, one for each row)
-#' all_passed(agent)
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_vals_not_equal_1.png")`
+#' }
+#' }
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' ## B: Using the validation function directly on the data (no `agent`)
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' tbl %>% 
-#'   col_vals_not_equal(vars(a), 6) %>%
+#'   col_vals_not_equal(columns = vars(a), value = 6) %>%
 #'   dplyr::pull(a)
+#' ```
 #'   
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
-#' expect_col_vals_not_equal(tbl, vars(a), 6)
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
 #' 
-#' # D: Using the test function
+#' ```r
+#' expect_col_vals_not_equal(tbl, columns = vars(a), value = 6)
+#' ```
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
-#' test_col_vals_not_equal(tbl, vars(a), 6)
+#' ## D: Using the test function
+#' 
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
+#' test_col_vals_not_equal(tbl, columns = vars(a), value = 6)
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -252,17 +277,19 @@ NULL
 #' @rdname col_vals_not_equal
 #' @import rlang
 #' @export
-col_vals_not_equal <- function(x,
-                               columns,
-                               value,
-                               na_pass = FALSE,
-                               preconditions = NULL,
-                               segments = NULL,
-                               actions = NULL,
-                               step_id = NULL,
-                               label = NULL,
-                               brief = NULL,
-                               active = TRUE) {
+col_vals_not_equal <- function(
+    x,
+    columns,
+    value,
+    na_pass = FALSE,
+    preconditions = NULL,
+    segments = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   # Get `columns` as a label
   columns_expr <- 
@@ -363,12 +390,14 @@ col_vals_not_equal <- function(x,
 #' @rdname col_vals_not_equal
 #' @import rlang
 #' @export
-expect_col_vals_not_equal <- function(object,
-                                      columns,
-                                      value,
-                                      na_pass = FALSE,
-                                      preconditions = NULL,
-                                      threshold = 1) {
+expect_col_vals_not_equal <- function(
+    object,
+    columns,
+    value,
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_vals_not_equal"
   
@@ -444,12 +473,14 @@ expect_col_vals_not_equal <- function(object,
 #' @rdname col_vals_not_equal
 #' @import rlang
 #' @export
-test_col_vals_not_equal <- function(object,
-                                    columns,
-                                    value,
-                                    na_pass = FALSE,
-                                    preconditions = NULL,
-                                    threshold = 1) {
+test_col_vals_not_equal <- function(
+    object,
+    columns,
+    value,
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
