@@ -50,36 +50,63 @@
 #'   
 #' @return A character vector.
 #'   
-#' @examples 
-#' # Taking the generic `pb_file` name for
-#' # a file, we add the current date to it
-#' # as a suffix
+#' @section Examples:
+#' 
+#' ## The basics of creating a filename with the current date
+#' 
+#' Taking the generic `"pb_file"` name for a file, we add the current date to it
+#' as a suffix.
+#' 
+#' ```r
 #' affix_date(filename = "pb_file")
+#' ```
+#' ```
+#' ## [1] "pb_file_2022-04-01"
+#' ```
 #' 
-#' # File extensions won't get in the way:
+#' File extensions won't get in the way:
+#' 
+#' ```r
 #' affix_date(filename = "pb_file.rds")
+#' ```
+#' ```
+#' ## [1] "pb_file_2022-04-01.rds"
+#' ```
 #' 
-#' # The date can be used as a prefix
+#' The date can be used as a prefix.
+#' 
+#' ```r
 #' affix_date(
 #'   filename = "pb_file",
 #'   position = "start"
 #' )
+#' ```
+#' ```
+#' ## [1] "2022-04-01_pb_file"
+#' ```
 #' 
-#' # The date pattern can be changed and so
-#' # can the delimiter
+#' The date pattern can be changed and so can the delimiter.
+#' 
+#' ```r
 #' affix_date(
 #'   filename = "pb_file.yml",
 #'   format = "%Y%m%d",
 #'   delimiter = "-"
 #' )
+#' ```
+#' ```
+#' ## [1] "pb_file-20220401.yml"
+#' ```
+#'
+#' ## Using a date-based filename in a **pointblank** workflow
+#'
+#' We can use a file-naming convention involving dates when writing output files
+#' immediately after interrogating. This is just one example (any workflow
+#' involving a `filename` argument is applicable). It's really advantageous to
+#' use date-based filenames when interrogating directly from YAML in a scheduled
+#' process.
 #' 
-#' if (interactive()) {
-#' 
-#' # We can use a file-naming convention
-#' # involving dates when writing output
-#' # files immediately after interrogating;
-#' # useful when interrogating directly
-#' # from YAML in a scheduled process
+#' ```r
 #' yaml_agent_interrogate(
 #'   filename = system.file(
 #'     "yaml", "agent-small_table.yml",
@@ -94,22 +121,30 @@
 #'     keep_tbl = TRUE,
 #'     keep_extracts = TRUE
 #'   )
+#' ```
 #' 
-#' }
+#' In the above, we used the written-to-disk agent (The
+#' `"agent-small_table.yml"` YAML file) for an interrogation via
+#' [yaml_agent_interrogate()]. Then, the results were written to disk as an RDS
+#' file. In the `filename` argument of [x_write_disk()], the [affix_date()]
+#' function was used to ensure that a daily run would produce a file whose name
+#' indicates the day of execution.
 #' 
 #' @family Utility and Helper Functions
 #' @section Function ID:
 #' 13-3
 #' 
 #' @seealso The [affix_datetime()] function provides the same features except it
-#'   produces a date-time string by default.
+#'   produces a datetime string by default.
 #' 
 #' @export
-affix_date <- function(filename,
-                       position = c("end", "start"),
-                       format = "%Y-%m-%d",
-                       delimiter = "_",
-                       utc_time = TRUE) {
+affix_date <- function(
+    filename,
+    position = c("end", "start"),
+    format = "%Y-%m-%d",
+    delimiter = "_",
+    utc_time = TRUE
+) {
   
   position <- match.arg(position)
   
@@ -123,16 +158,16 @@ affix_date <- function(filename,
   )
 }
 
-#' Put the current date-time into a file name
+#' Put the current datetime into a file name
 #' 
 #' @description
-#' This function helps to affix the current date-time to a filename. This is
+#' This function helps to affix the current datetime to a filename. This is
 #' useful when writing *agent* and/or *informant* objects to disk as part of a
-#' continuous process. The date-time string can be based on the current UTC time
-#' or the local system time. The date-time can be affixed either to the end of
+#' continuous process. The datetime string can be based on the current UTC time
+#' or the local system time. The datetime can be affixed either to the end of
 #' the filename (before the file extension) or at the beginning with a
 #' customizable delimiter. Optionally, the time zone information can be
-#' included. If the date-time is based on the local system time, the user system
+#' included. If the datetime is based on the local system time, the user system
 #' time zone is shown with the format `<time>(+/-)hhmm`. If using UTC time, then
 #' the `<time>Z` format is adopted.
 #' 
@@ -144,18 +179,18 @@ affix_date <- function(filename,
 #' components affixed to the filenames.
 #' 
 #' @inheritParams affix_date
-#' @param position Where to place the formatted date-time. This could either be
+#' @param position Where to place the formatted datetime. This could either be
 #'   at the `"end"` of the filename (the default) or at the `"start"`.
 #' @param format A [base::strptime()] format string for formatting the
-#'   date-time. By default, this is `"%Y-%m-%dT%H:%M:%S"` which expresses the
+#'   datetime. By default, this is `"%Y-%m-%dT%H:%M:%S"` which expresses the
 #'   date according to the ISO 8601 standard. For example, if the current
-#'   date-time is `2020-12-04 13:11:23`, the formatted string would become
+#'   datetime is `2020-12-04 13:11:23`, the formatted string would become
 #'   `"2020-12-04T13:11:23"`. Refer to the documentation on [base::strptime()]
 #'   for conversion specifications if planning to use a different format string.
-#' @param delimiter The delimiter characters to use for separating the date-time
+#' @param delimiter The delimiter characters to use for separating the datetime
 #'   string from the original file name.
 #' @param utc_time An option for whether to use the current UTC time to
-#'   establish the date-time (the default, with `TRUE`), or, use the system's
+#'   establish the datetime (the default, with `TRUE`), or, use the system's
 #'   local time (`FALSE`).
 #' @param add_tz Should the time zone (as an offset from UTC) be provided? If
 #'   `TRUE` then the UTC offset will be either provided as `<time>Z` (if
@@ -163,42 +198,90 @@ affix_date <- function(filename,
 #'
 #' @return A character vector.
 #' 
-#' @examples 
-#' # Taking the generic `pb_file` name for
-#' # a file, we add the current date-time to it
-#' # as a suffix
+#' @section Examples:
+#' 
+#' ## The basics of creating a filename with the current date and time
+#' 
+#' Taking the generic `"pb_file"` name for a file, we add the current datetime
+#' to it as a suffix.
+#' 
+#' ```r
 #' affix_datetime(filename = "pb_file")
+#' ```
+#' ```
+#' ## [1] "pb_file_2022-04-01_00-32-53"
+#' ```
 #' 
-#' # File extensions won't get in the way:
+#' File extensions won't get in the way:
+#' 
+#' ```r
 #' affix_datetime(filename = "pb_file.rds")
+#' ```
+#' ```
+#' ## [1] "pb_file_2022-04-01_00-32-53.rds"
+#' ```
 #' 
-#' # The date-time can be used as a prefix
+#' The datetime can be used as a prefix.
+#' 
+#' ```r
 #' affix_datetime(
 #'   filename = "pb_file",
 #'   position = "start"
 #' )
+#' ```
+#' ```
+#' ## [1] "2022-04-01_00-32-53_pb_file"
+#' ```
 #' 
-#' # The date-time pattern can be changed and so
-#' # can the delimiter
+#' The datetime pattern can be changed and so can the delimiter.
+#' 
+#' ```r
 #' affix_datetime(
 #'   filename = "pb_file.yml",
 #'   format = "%Y%m%d_%H%M%S",
 #'   delimiter = "-"
 #' )
+#' ```
+#' ```
+#' ## [1] "pb_file-20220401_003253.yml"
+#' ```
 #' 
-#' # Time zone information can be included
+#' Time zone information can be included. By default, all datetimes are given in
+#' the UTC time zone.
+#' 
+#' ```r
 #' affix_datetime(
 #'   filename = "pb_file.yml",
 #'   add_tz = TRUE
 #' )
+#' ```
+#' ```
+#' ## [1] "pb_file_2022-04-01_00-32-53Z.yml"
+#' ```
 #' 
-#' if (interactive()) {
+#' We can use the system's local time zone with `utc_time = FALSE`.
 #' 
-#' # We can use a file-naming convention
-#' # involving date-times when writing output
-#' # files immediately after interrogating;
-#' # useful when interrogating directly
-#' # from YAML in a scheduled process
+#' ```r
+#' affix_datetime(
+#'   filename = "pb_file.yml",
+#'   utc_time = FALSE,
+#'   add_tz = TRUE
+#' )
+#' ```
+#' ```
+#' ## [1] "pb_file_2022-03-31_20-32-53-0400.yml"
+#' ```
+#' 
+#' ## Using a datetime-based filename in a **pointblank** workflow
+#'
+#' We can use a file-naming convention involving datetimes when writing output
+#' files immediately after interrogating. This is just one example (any workflow
+#' involving a `filename` argument is applicable). It's really advantageous to
+#' use datetime-based filenames when interrogating directly from YAML in a
+#' scheduled process, especially if multiple validation runs per day are being
+#' executed on the same target table.
+#' 
+#' ```r
 #' yaml_agent_interrogate(
 #'   filename = system.file(
 #'     "yaml", "agent-small_table.yml",
@@ -213,8 +296,14 @@ affix_date <- function(filename,
 #'     keep_tbl = TRUE,
 #'     keep_extracts = TRUE
 #'   )
+#' ```
 #' 
-#' }
+#' In the above, we used the written-to-disk agent (The
+#' `"agent-small_table.yml"` YAML file) for an interrogation via
+#' [yaml_agent_interrogate()]. Then, the results were written to disk as an RDS
+#' file. In the `filename` argument of [x_write_disk()], the [affix_datetime()]
+#' function was used to ensure that frequent runs would produce files whose
+#' names indicate the day and time of execution.
 #'
 #' @family Utility and Helper Functions
 #' @section Function ID:
@@ -224,12 +313,14 @@ affix_date <- function(filename,
 #'   produces a date string by default.
 #' 
 #' @export
-affix_datetime <- function(filename,
-                           position = c("end", "start"),
-                           format = "%Y-%m-%d_%H-%M-%S",
-                           delimiter = "_",
-                           utc_time = TRUE,
-                           add_tz = FALSE) {
+affix_datetime <- function(
+    filename,
+    position = c("end", "start"),
+    format = "%Y-%m-%d_%H-%M-%S",
+    delimiter = "_",
+    utc_time = TRUE,
+    add_tz = FALSE
+) {
   
   position <- match.arg(position)
   
@@ -243,12 +334,14 @@ affix_datetime <- function(filename,
   )
 }
 
-affix_time_to_filename <- function(filename,
-                                   position,
-                                   format,
-                                   delimiter,
-                                   utc_time,
-                                   add_tz) {
+affix_time_to_filename <- function(
+    filename,
+    position,
+    format,
+    delimiter,
+    utc_time,
+    add_tz
+) {
   
   curr_time <- Sys.time()
   
