@@ -50,27 +50,45 @@
 #'   
 #' @return A `ptblank_agent` object.
 #'   
-#' @examples
-#' if (interactive()) {
+#' @section Examples:
+#'  
+#' Create a simple table with two columns of numerical values.
 #' 
-#' # Create a simple table with two
-#' # columns of numerical values
+#' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
 #'     a = c(5, 7, 6, 5, 8, 7),
 #'     b = c(7, 1, 0, 0, 0, 3)
 #'   )
 #' 
-#' # Validate that values in column
-#' # `a` from `tbl` are always > 5,
-#' # using `interrogate()` carries out
-#' # the validation plan and completes
-#' # the whole process
-#' agent <-
-#'   create_agent(tbl = tbl) %>%
-#'   col_vals_gt(vars(a), value = 5) %>%
-#'   interrogate()
+#' tbl
+#' ```
 #' 
+#' Validate that values in column `a` from `tbl` are always less than `5`. Using
+#' `interrogate()` carries out the validation plan and completes the whole
+#' process.
+#' 
+#' ```r
+#' agent <-
+#'   create_agent(
+#'     tbl = tbl,
+#'     label = "`interrogate()` example"
+#'   ) %>%
+#'   col_vals_gt(columns = vars(a), value = 5) %>%
+#'   interrogate()
+#' ```
+#' 
+#' We can print the resulting object to see the validation report.
+#' 
+#' ```r
+#' agent
+#' ```
+#' 
+#' \if{html}{
+#' 
+#' \out{
+#' `r pb_get_image_tag(file = "man_interrogate_1.png")`
+#' }
 #' }
 #' 
 #' @family Interrogate and Report
@@ -78,12 +96,14 @@
 #' 6-1
 #' 
 #' @export
-interrogate <- function(agent,
-                        extract_failed = TRUE,
-                        get_first_n = NULL,
-                        sample_n = NULL,
-                        sample_frac = NULL,
-                        sample_limit = 5000) {
+interrogate <- function(
+    agent,
+    extract_failed = TRUE,
+    get_first_n = NULL,
+    sample_n = NULL,
+    sample_frac = NULL,
+    sample_limit = 5000
+) {
   
   #
   # INITIAL PROCESSING OF AGENT
@@ -340,9 +360,11 @@ interrogate <- function(agent,
       columns_str_add <- paste0("pb_is_good_", seq(j), collapse = " + ")
 
       # Create function for validating step functions conjointly
-      tbl_val_conjointly <- function(columns_str_add,
-                                     columns_str_vec,
-                                     validation_n) {
+      tbl_val_conjointly <- function(
+        columns_str_add,
+        columns_str_vec,
+        validation_n
+      ) {
        
         # TODO: Require check to ensure that the validation functions used
         # are entirely of the combined set of `col_vals_*()`, `col_is_*()`,
@@ -703,10 +725,12 @@ interrogate <- function(agent,
 
 # nocov start
 
-get_time_duration <- function(start_time,
-                              end_time,
-                              units = "secs",
-                              round = 4) {
+get_time_duration <- function(
+    start_time,
+    end_time,
+    units = "secs",
+    round = 4
+) {
   
   round(
     as.numeric(difftime(time1 = end_time, time2 = start_time, units = units)),
@@ -714,8 +738,10 @@ get_time_duration <- function(start_time,
   )
 }
 
-create_cli_header_a <- function(validation_steps,
-                                quiet) {
+create_cli_header_a <- function(
+    validation_steps,
+    quiet
+) {
   
   if (quiet) return()
   
@@ -743,10 +769,12 @@ create_cli_footer_a <- function(quiet) {
   cli::cli_h1(interrogation_progress_footer)
 }
 
-create_post_step_cli_output_a <- function(agent,
-                                          i,
-                                          time_diff_s,
-                                          quiet) {
+create_post_step_cli_output_a <- function(
+    agent,
+    i,
+    time_diff_s,
+    quiet
+) {
   
   if (quiet) return()
   
@@ -849,10 +877,12 @@ create_post_step_cli_output_a <- function(agent,
 
 # nocov end
 
-check_table_with_assertion <- function(agent,
-                                       idx,
-                                       table,
-                                       assertion_type) {
+check_table_with_assertion <- function(
+    agent,
+    idx,
+    table,
+    assertion_type
+) {
   
   # nolint start
   
@@ -959,6 +989,11 @@ check_table_with_assertion <- function(agent,
         idx = idx,
         table = table
       ),
+      "col_count_match" = interrogate_col_count_match(
+        agent = agent,
+        idx = idx,
+        table = table
+      ),
       "tbl_match" = interrogate_tbl_match(
         agent = agent,
         idx = idx,
@@ -969,10 +1004,12 @@ check_table_with_assertion <- function(agent,
   # nolint end
 }
 
-interrogate_comparison <- function(agent,
-                                   idx,
-                                   table,
-                                   assertion_type) {
+interrogate_comparison <- function(
+    agent,
+    idx,
+    table,
+    assertion_type
+) {
 
   # Get operator values for all assertion types involving
   # simple operator comparisons
@@ -1020,11 +1057,13 @@ interrogate_comparison <- function(agent,
 }
 
 # Function for validating comparison step functions
-tbl_val_comparison <- function(table,
-                               column,
-                               operator,
-                               value,
-                               na_pass) {
+tbl_val_comparison <- function(
+    table,
+    column,
+    operator,
+    value,
+    na_pass
+) {
   
   # Ensure that the input `table` is actually a table object
   tbl_validity_check(table = table)
@@ -1058,10 +1097,12 @@ tbl_val_comparison <- function(table,
   }
 }
 
-interrogate_between <- function(agent,
-                                idx,
-                                table,
-                                assertion_type) {
+interrogate_between <- function(
+    agent,
+    idx,
+    table,
+    assertion_type
+) {
   
   # Get the set values for the expression
   set <- get_values_at_idx(agent = agent, idx = idx)
@@ -1106,13 +1147,16 @@ interrogate_between <- function(agent,
   tbl_evaled
 }
 
-tbl_vals_between <- function(table,
-                             column,
-                             left,
-                             right,
-                             inclusive,
-                             na_pass,
-                             assertion_type) {
+tbl_vals_between <- function(
+    table,
+    column,
+    left,
+    right,
+    inclusive,
+    na_pass,
+    assertion_type
+) {
+  
   # Ensure that the input `table` is actually a table object
   tbl_validity_check(table = table)
   
@@ -1248,10 +1292,12 @@ tbl_vals_between <- function(table,
     ))
 }
 
-interrogate_set <- function(agent,
-                            idx,
-                            table,
-                            assertion_type) {
+interrogate_set <- function(
+    agent,
+    idx,
+    table,
+    assertion_type
+) {
 
   # Get the set values for the expression
   set <- get_values_at_idx(agent = agent, idx = idx)
@@ -1265,9 +1311,11 @@ interrogate_set <- function(agent,
   if (assertion_type == "col_vals_in_set") {
     
     # Create function for validating the `col_vals_in_set()` step
-    tbl_val_in_set <- function(table,
-                               column,
-                               na_pass) {
+    tbl_val_in_set <- function(
+      table,
+      column,
+      na_pass
+    ) {
       
       # Ensure that the input `table` is actually a table object
       tbl_validity_check(table = table)
@@ -1304,9 +1352,11 @@ interrogate_set <- function(agent,
   if (assertion_type == "col_vals_make_set") {
     
     # Create function for validating the `col_vals_make_set()` step
-    tbl_vals_make_set <- function(table,
-                                  column,
-                                  na_pass) {
+    tbl_vals_make_set <- function(
+      table,
+      column,
+      na_pass
+    ) {
       
       # Ensure that the input `table` is actually a table object
       tbl_validity_check(table = table)
@@ -1376,9 +1426,11 @@ interrogate_set <- function(agent,
   if (assertion_type == "col_vals_make_subset") {
     
     # Create function for validating the `col_vals_make_subset()` step
-    tbl_vals_make_subset <- function(table,
-                                     column,
-                                     na_pass) {
+    tbl_vals_make_subset <- function(
+      table,
+      column,
+      na_pass
+    ) {
       
       # Ensure that the input `table` is actually a table object
       tbl_validity_check(table = table)
@@ -1439,9 +1491,11 @@ interrogate_set <- function(agent,
   if (assertion_type == "col_vals_not_in_set") {
     
     # Create function for validating the `col_vals_not_in_set()` step function
-    tbl_val_not_in_set <- function(table,
-                                   column,
-                                   na_pass) {
+    tbl_val_not_in_set <- function(
+      table,
+      column,
+      na_pass
+    ) {
       
       # Ensure that the input `table` is actually a table object
       tbl_validity_check(table = table)
@@ -1478,10 +1532,12 @@ interrogate_set <- function(agent,
   tbl_evaled
 }
 
-interrogate_direction <- function(agent,
-                                  idx,
-                                  table,
-                                  assertion_type) {
+interrogate_direction <- function(
+    agent,
+    idx,
+    table,
+    assertion_type
+) {
   
   # Obtain the target column as a symbol
   column <- get_column_as_sym_at_idx(agent = agent, idx = idx)
@@ -1501,10 +1557,12 @@ interrogate_direction <- function(agent,
 
   # Create function for validating any `col_vals_increasing()` and
   # `col_vals_decreasing()` steps
-  tbl_val_direction <- function(table,
-                                column,
-                                na_pass,
-                                direction) {
+  tbl_val_direction <- function(
+    table,
+    column,
+    na_pass,
+    direction
+  ) {
     
     # Exit if the table is from the `mssql` source 
     if (is_tbl_mssql(table)) {
@@ -1620,9 +1678,11 @@ interrogate_direction <- function(agent,
     )
 }
 
-interrogate_regex <- function(agent,
-                              idx,
-                              table) {
+interrogate_regex <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Get the regex matching statement
   regex <- get_values_at_idx(agent = agent, idx = idx)
@@ -1636,11 +1696,13 @@ interrogate_regex <- function(agent,
   tbl_type <- agent$tbl_src
   
   # Create function for validating the `col_vals_regex()` step function
-  tbl_val_regex <- function(table,
-                            tbl_type,
-                            column,
-                            regex,
-                            na_pass) {
+  tbl_val_regex <- function(
+    table,
+    tbl_type,
+    column,
+    regex,
+    na_pass
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -1692,6 +1754,19 @@ interrogate_regex <- function(agent,
           is.na(pb_is_good_) ~ na_pass,
           TRUE ~ pb_is_good_
         ))
+    
+    } else if (tbl_type == "bigquery") {
+      
+      tbl <- 
+        table %>%
+        dplyr::mutate(
+          pb_is_good_ = ifelse(
+            !is.na({{ column }}), REGEXP_CONTAINS({{ column }}, regex), NA)
+        ) %>%
+        dplyr::mutate(pb_is_good_ = dplyr::case_when(
+          is.na(pb_is_good_) ~ na_pass,
+          TRUE ~ pb_is_good_
+        ))
       
     } else if (tbl_type == "duckdb") {
 
@@ -1736,9 +1811,11 @@ interrogate_regex <- function(agent,
   )
 }
 
-interrogate_within_spec <- function(agent,
-                                    idx,
-                                    table) {
+interrogate_within_spec <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Get the specification text
   spec <- get_values_at_idx(agent = agent, idx = idx)
@@ -1752,11 +1829,13 @@ interrogate_within_spec <- function(agent,
   tbl_type <- agent$tbl_src
   
   # Create function for validating the `col_vals_within_spec()` step function
-  tbl_val_within_spec <- function(table,
-                                  tbl_type,
-                                  column,
-                                  spec,
-                                  na_pass) {
+  tbl_val_within_spec <- function(
+    table,
+    tbl_type,
+    column,
+    spec,
+    na_pass
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -1949,16 +2028,20 @@ interrogate_within_spec <- function(agent,
   )
 }
 
-interrogate_expr <- function(agent,
-                             idx,
-                             table) {
+interrogate_expr <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Get the expression
   expr <- get_values_at_idx(agent = agent, idx = idx)
   
   # Create function for validating the `col_vals_expr()` step function
-  tbl_val_expr <- function(table,
-                           expr) {
+  tbl_val_expr <- function(
+    table,
+    expr
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -1974,9 +2057,11 @@ interrogate_expr <- function(agent,
   pointblank_try_catch(tbl_val_expr(table = table, expr = expr))
 }
 
-interrogate_specially <- function(agent,
-                                  idx,
-                                  x) {
+interrogate_specially <- function(
+    agent,
+    idx,
+    x
+) {
   
   # Get the user-defined function
   fn <- get_values_at_idx(agent = agent, idx = idx)[[1]]
@@ -2028,16 +2113,20 @@ interrogate_specially <- function(agent,
   pointblank_try_catch(val_with_fn(x = x, fn = fn))
 }
 
-interrogate_null <- function(agent,
-                             idx,
-                             table) {
+interrogate_null <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Obtain the target column as a symbol
   column <- get_column_as_sym_at_idx(agent = agent, idx = idx)
   
   # Create function for validating the `col_vals_null()` step function
-  tbl_val_null <- function(table,
-                           column) {
+  tbl_val_null <- function(
+    table,
+    column
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -2059,16 +2148,20 @@ interrogate_null <- function(agent,
   pointblank_try_catch(tbl_val_null(table = table, column = {{ column }}))
 }
 
-interrogate_not_null <- function(agent,
-                                 idx,
-                                 table) {
+interrogate_not_null <- function(
+    agent,
+    idx,
+    table
+) {
 
   # Obtain the target column as a symbol
   column <- get_column_as_sym_at_idx(agent = agent, idx = idx)
   
   # Create function for validating the `col_vals_null()` step function
-  tbl_val_not_null <- function(table,
-                               column) {
+  tbl_val_not_null <- function(
+    table,
+    column
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -2090,9 +2183,11 @@ interrogate_not_null <- function(agent,
   pointblank_try_catch(tbl_val_not_null(table = table, column = {{ column }}))
 }
 
-interrogate_col_exists <- function(agent,
-                                   idx,
-                                   table) {
+interrogate_col_exists <- function(
+    agent,
+    idx,
+    table
+) {
 
   # Get the column names for the table
   column_names <- get_all_cols(agent = agent)
@@ -2101,9 +2196,11 @@ interrogate_col_exists <- function(agent,
   column <- get_column_as_sym_at_idx(agent = agent, idx = idx)
   
   # Create function for validating the `col_exists()` step function
-  tbl_col_exists <- function(table,
-                             column,
-                             column_names) {
+  tbl_col_exists <- function(
+    table,
+    column,
+    column_names
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -2121,18 +2218,22 @@ interrogate_col_exists <- function(agent,
   )
 }
 
-interrogate_col_type <- function(agent,
-                                 idx,
-                                 table,
-                                 assertion_type) {
+interrogate_col_type <- function(
+    agent,
+    idx,
+    table,
+    assertion_type
+) {
   
   # Obtain the target column as a symbol
   column <- get_column_as_sym_at_idx(agent = agent, idx = idx)
   
   # Create function for validating the `col_is_*()` step functions
-  tbl_col_is <- function(table,
-                         column,
-                         assertion_type) {
+  tbl_col_is <- function(
+    table,
+    column,
+    assertion_type
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -2175,9 +2276,11 @@ interrogate_col_type <- function(agent,
   )
 }
 
-interrogate_distinct <- function(agent,
-                                 idx,
-                                 table) {
+interrogate_distinct <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Determine if grouping columns are provided in the test
   # for distinct rows and parse the column names
@@ -2193,6 +2296,12 @@ interrogate_distinct <- function(agent,
         unlist()
     }
     
+    if (length(column_names) == 1 && column_names == "NA") {
+      if (uses_tidyselect(expr_text = agent$validation_set$columns_expr[idx])) {
+        column_names <- character(0)
+      }
+    }
+    
   } else if (is.na(agent$validation_set$column[idx] %>% unlist())) {
     column_names <- get_all_cols(agent = agent)
   }
@@ -2200,12 +2309,15 @@ interrogate_distinct <- function(agent,
   col_syms <- rlang::syms(column_names)
   
   # Create function for validating the `rows_distinct()` step function
-  tbl_rows_distinct <- function(table,
-                                column_names,
-                                col_syms) {
+  tbl_rows_distinct <- function(
+    table,
+    column_names,
+    col_syms
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
+    column_validity_has_columns(columns = column_names)
     
     table %>%
       dplyr::select({{ column_names }}) %>%
@@ -2216,10 +2328,13 @@ interrogate_distinct <- function(agent,
   
   # nocov start
   
-  # Create another variation of `tbl_rows_distinct()` that works for MySQL
-  tbl_rows_distinct_mysql <- function(table,
-                                      column_names,
-                                      col_syms) {
+  # Create a variation of `tbl_rows_distinct()` that works
+  # for MySQL and for BigQuery
+  tbl_rows_distinct_2 <- function(
+    table,
+    column_names,
+    col_syms
+  ) {
 
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -2240,9 +2355,9 @@ interrogate_distinct <- function(agent,
   }
   
   # Perform the validation of the table
-  if (agent$tbl_src == "mysql") {
+  if (agent$tbl_src %in% c("mysql", "bigquery")) {
     pointblank_try_catch(
-      tbl_rows_distinct_mysql(
+      tbl_rows_distinct_2(
         table = table,
         column_names = {{ column_names }},
         col_syms = col_syms
@@ -2261,9 +2376,11 @@ interrogate_distinct <- function(agent,
   # nocov end
 }
 
-interrogate_complete <- function(agent,
-                                 idx,
-                                 table) {
+interrogate_complete <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Determine if grouping columns are provided in the test
   # for distinct rows and parse the column names
@@ -2279,6 +2396,12 @@ interrogate_complete <- function(agent,
         unlist()
     }
     
+    if (length(column_names) == 1 && column_names == "NA") {
+      if (uses_tidyselect(expr_text = agent$validation_set$columns_expr[idx])) {
+        column_names <- character(0)
+      }
+    }
+    
   } else if (is.na(agent$validation_set$column[idx] %>% unlist())) {
     column_names <- get_all_cols(agent = agent)
   }
@@ -2286,12 +2409,15 @@ interrogate_complete <- function(agent,
   col_syms <- rlang::syms(column_names)
   
   # Create function for validating the `rows_complete()` step function
-  tbl_rows_complete <- function(table,
-                                column_names,
-                                col_syms) {
+  tbl_rows_complete <- function(
+    table,
+    column_names,
+    col_syms
+  ) {
     
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
+    column_validity_has_columns(columns = column_names)
     
     if (is_tbl_dbi(table) || is_tbl_spark(table)) {
       
@@ -2326,9 +2452,11 @@ interrogate_complete <- function(agent,
   )
 }
 
-interrogate_col_schema_match <- function(agent,
-                                         idx,
-                                         table) {
+interrogate_col_schema_match <- function(
+    agent,
+    idx,
+    table
+) {
 
   # Get the reference `col_schema` object (this is user-supplied)
   table_schema_y <- agent$validation_set$values[[idx]]
@@ -2339,6 +2467,7 @@ interrogate_col_schema_match <- function(agent,
   if (inherits(table, "tbl_dbi") || inherits(table, "tbl_spark")) {
     
     if (inherits(table_schema_y, "sql_type")) {
+      
       if (all(!is.na(agent$db_col_types))) {
         
         table_schema_x <-
@@ -2365,9 +2494,11 @@ interrogate_col_schema_match <- function(agent,
   }
   
   # Create function for validating the `col_schema_match()` step function
-  tbl_col_schema_match <- function(table,
-                                   table_schema_x,
-                                   table_schema_y) {
+  tbl_col_schema_match <- function(
+    table,
+    table_schema_x,
+    table_schema_y
+  ) {
 
     # Ensure that the input `table` is actually a table object
     tbl_validity_check(table = table)
@@ -2446,7 +2577,7 @@ interrogate_col_schema_match <- function(agent,
       dplyr::tibble(pb_is_good_ = all(unit_results))
       
     } else {
-    
+      
       # Check for exact matching between the reference schema and
       # the user-defined schema
       if (identical(table_schema_x, table_schema_y)) {
@@ -2467,25 +2598,32 @@ interrogate_col_schema_match <- function(agent,
   )
 }
 
-interrogate_row_count_match <- function(agent,
-                                        idx,
-                                        table) {
-  
-  # Get the comparison table (this is user-supplied)
-  tbl_compare <- materialize_table(tbl = agent$validation_set$values[[idx]])
+interrogate_row_count_match <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Create function for validating the `row_count_match()` step function
-  tbl_row_count_match <- function(table,
-                                  tbl_compare) {
+  tbl_row_count_match <- function(table) {
     
-    # Ensure that the input `table` and `tbl_compare` objects
-    # are actually table objects
-    # TODO: improve failure message for check of `tbl_compare`
     tbl_validity_check(table = table)
-    tbl_validity_check(table = tbl_compare)
+    
+    count <- agent$validation_set$values[[idx]]
+    
+    if (!is.numeric(count)) {
+      
+      # Get the comparison table (this is user-supplied)
+      tbl_compare <- materialize_table(tbl = agent$validation_set$values[[idx]])
+      
+      # TODO: improve failure message for check of `tbl_compare`
+      tbl_validity_check(table = tbl_compare)
+      
+      count <- get_table_total_rows(tbl_compare)
+    } 
     
     # Check for exact matching in row counts between the two tables
-    if (get_table_total_rows(table) == get_table_total_rows(tbl_compare)) {
+    if (get_table_total_rows(table) == count) {
       dplyr::tibble(pb_is_good_ = TRUE)
     } else {
       dplyr::tibble(pb_is_good_ = FALSE)
@@ -2494,23 +2632,62 @@ interrogate_row_count_match <- function(agent,
   
   # Perform the validation of the table 
   pointblank_try_catch(
-    tbl_row_count_match(
-      table = table,
-      tbl_compare = tbl_compare
-    )
+    tbl_row_count_match(table = table)
   )
 }
 
-interrogate_tbl_match <- function(agent,
-                                  idx,
-                                  table) {
+interrogate_col_count_match <- function(
+    agent,
+    idx,
+    table
+) {
+  
+  # Create function for validating the `col_count_match()` step function
+  tbl_col_count_match <- function(table) {
+    
+    tbl_validity_check(table = table)
+    
+    count <- agent$validation_set$values[[idx]]
+    
+    if (!is.numeric(count)) {
+      
+      # Get the comparison table (this is user-supplied)
+      tbl_compare <- materialize_table(tbl = agent$validation_set$values[[idx]])
+      
+      # TODO: improve failure message for check of `tbl_compare`
+      tbl_validity_check(table = tbl_compare)
+      
+      count <- get_table_total_columns(tbl_compare)
+    } 
+    
+    # Check for exact matching in row counts between the two tables
+    if (get_table_total_columns(table) == count) {
+      dplyr::tibble(pb_is_good_ = TRUE)
+    } else {
+      dplyr::tibble(pb_is_good_ = FALSE)
+    }
+  }
+  
+  # Perform the validation of the table 
+  pointblank_try_catch(
+    tbl_col_count_match(table = table)
+  )
+}
+
+interrogate_tbl_match <- function(
+    agent,
+    idx,
+    table
+) {
   
   # Get the comparison table (this is user-supplied)
   tbl_compare <- materialize_table(tbl = agent$validation_set$values[[idx]])
   
   # Create function for validating the `tbl_match()` step function
-  tbl_match <- function(table,
-                        tbl_compare) {
+  tbl_match <- function(
+    table,
+    tbl_compare
+  ) {
     
     # Ensure that the input `table` and `tbl_compare` objects
     # are actually table objects
@@ -2609,9 +2786,11 @@ tbl_validity_check <- function(table) {
 # nolint start
 
 # Validity checks for the column and value 
-column_validity_checks_column_value <- function(table,
-                                                column,
-                                                value) {
+column_validity_checks_column_value <- function(
+    table,
+    column,
+    value
+) {
   
   table_colnames <- colnames(table)
   
@@ -2638,9 +2817,22 @@ column_validity_checks_column_value <- function(table,
 
 # nolint end
 
+# Validity check for presence of columns
+column_validity_has_columns <- function(columns) {
+  
+  if (length(columns) < 1) {
+    stop(
+      "The column selection statement that was used yielded no columns.",
+      call. = FALSE
+    )
+  }
+}
+
 # Validity check for the column
-column_validity_checks_column <- function(table,
-                                          column) {
+column_validity_checks_column <- function(
+    table,
+    column
+) {
   
   table_colnames <- colnames(table)
   
@@ -2654,10 +2846,12 @@ column_validity_checks_column <- function(table,
 }
 
 # Validity checks for `tbl_val_ib_*()` functions
-column_validity_checks_ib_nb <- function(table,
-                                         column,
-                                         left,
-                                         right) {
+column_validity_checks_ib_nb <- function(
+    table,
+    column,
+    left,
+    right
+) {
   
   table_colnames <- colnames(table)
   
@@ -2714,9 +2908,11 @@ pointblank_try_catch <- function(expr) {
   eval_list
 }
 
-add_reporting_data <- function(agent,
-                               idx,
-                               tbl_checked) {
+add_reporting_data <- function(
+    agent,
+    idx,
+    tbl_checked
+) {
   
   if (!inherits(tbl_checked, "table_eval")) {
     
@@ -2817,9 +3013,11 @@ add_reporting_data <- function(agent,
   determine_action(agent = agent, idx = idx, false_count = n_failed)
 }
 
-perform_action <- function(agent,
-                           idx,
-                           type) {
+perform_action <- function(
+    agent,
+    idx,
+    type
+) {
 
   actions <- 
     agent$validation_set[[idx, "actions"]] %>%
@@ -3012,14 +3210,16 @@ perform_end_action <- function(agent) {
   return(NULL)
 }
 
-add_table_extract <- function(agent,
-                              idx,
-                              tbl_checked,
-                              extract_failed,
-                              get_first_n,
-                              sample_n,
-                              sample_frac,
-                              sample_limit) {
+add_table_extract <- function(
+    agent,
+    idx,
+    tbl_checked,
+    extract_failed,
+    get_first_n,
+    sample_n,
+    sample_frac,
+    sample_limit
+) {
 
   if (!extract_failed) {
     return(agent)
@@ -3108,9 +3308,11 @@ add_table_extract <- function(agent,
   agent
 }
 
-determine_action <- function(agent,
-                             idx,
-                             false_count) {
+determine_action <- function(
+    agent,
+    idx,
+    false_count
+) {
 
   al <- agent$validation_set[[idx, "actions"]] %>% unlist(recursive = FALSE)
   n <- agent$validation_set[[idx, "n"]]
