@@ -1470,12 +1470,14 @@ test_that("Interrogating simply returns the expected results", {
   # row_count_match()
   #
   
+  # Using comparison tables
+  
   # Use the `row_count_match()` function to perform
   # a simple validation step
   tbl_result <- 
     small_table %>%
     row_count_match(
-      tbl_compare = pointblank::small_table,
+      count = pointblank::small_table,
       actions = warn_on_fail()
     )
   
@@ -1486,7 +1488,7 @@ test_that("Interrogating simply returns the expected results", {
   # another simple validation step
   tbl_result <- 
     small_table %>%
-    row_count_match(tbl_compare = ~ pointblank::small_table)
+    row_count_match(count = ~ pointblank::small_table)
   
   # Expect that `tbl_result` is equivalent to `small_table`
   expect_equivalent(small_table, tbl_result)
@@ -1496,7 +1498,7 @@ test_that("Interrogating simply returns the expected results", {
     tbl_result <- 
       tbl_complete_yes %>%
       row_count_match(
-        tbl_compare = pointblank::small_table,
+        count = pointblank::small_table,
         actions = warn_on_fail()
       )
   )
@@ -1511,7 +1513,158 @@ test_that("Interrogating simply returns the expected results", {
     tbl_result <- 
       tbl_complete_yes %>%
       row_count_match(
-        tbl_compare = pointblank::small_table,
+        count = pointblank::small_table,
+        actions = stop_on_fail()
+      )
+  )
+  
+  # Using literal values
+  
+  # Use the `row_count_match()` function to perform
+  # a simple validation step
+  tbl_result <- 
+    small_table %>%
+    row_count_match(
+      count = 13,
+      actions = warn_on_fail()
+    )
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Use the `row_count_match()` function to perform
+  # another simple validation step
+  tbl_result <- 
+    small_table %>%
+    row_count_match(count = 13L)
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      row_count_match(
+        count = 15,
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl_complete_yes`
+  expect_equivalent(tbl_complete_yes, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      row_count_match(
+        count = 15,
+        actions = stop_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is never created
+  expect_false(exists("tbl_result"))
+  
+  #
+  # col_count_match()
+  #
+  
+  # Using comparison tables
+  
+  # Use the `col_count_match()` function to perform
+  # a simple validation step
+  tbl_result <- 
+    small_table %>%
+    col_count_match(
+      count = pointblank::small_table,
+      actions = warn_on_fail()
+    )
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Use the `col_count_match()` function to perform
+  # another simple validation step
+  tbl_result <- 
+    small_table %>%
+    col_count_match(count = ~ pointblank::small_table)
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      col_count_match(
+        count = pointblank::small_table,
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl_complete_yes`
+  expect_equivalent(tbl_complete_yes, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      col_count_match(
+        count = pointblank::small_table,
+        actions = stop_on_fail()
+      )
+  )
+  
+  # Using literal values
+  
+  # Use the `col_count_match()` function to perform
+  # a simple validation step
+  tbl_result <- 
+    small_table %>%
+    col_count_match(
+      count = 8,
+      actions = warn_on_fail()
+    )
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Use the `col_count_match()` function to perform
+  # another simple validation step
+  tbl_result <- 
+    small_table %>%
+    col_count_match(count = 8L)
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      col_count_match(
+        count = 15,
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl_complete_yes`
+  expect_equivalent(tbl_complete_yes, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      col_count_match(
+        count = 15,
         actions = stop_on_fail()
       )
   )
